@@ -12,13 +12,11 @@ info: |
 includes: [propertyHelper.js]
 ---*/
 
-assert.sameValue(
-  Map.prototype.get.length, 1,
-  'The value of `Map.prototype.get.length` is `1`'
-);
-
-verifyNotEnumerable(Map.prototype.get, 'length');
-verifyNotWritable(Map.prototype.get, 'length');
-verifyConfigurable(Map.prototype.get, 'length');
+verifyProperty(Map.prototype.get, "length", {
+  value: 1,
+  writable: false,
+  enumerable: false,
+  configurable: true
+});
 
 reportCompare(0, 0);
